@@ -68,6 +68,7 @@ class MainWind(QMainWindow, Ui_mainwind):
         self.thread.destroyed.connect(sys.exit())
 
     def handle_elements(self):
+        self.initialize_window_on_screen_center()
         self.cpudtmbt.clicked.connect(self.cyclwind.exec)
         self.mmscexbt.clicked.connect(self.sostwind.exec)
         self.swphexbt.clicked.connect(self.phptwind.exec)
@@ -85,7 +86,6 @@ class MainWind(QMainWindow, Ui_mainwind):
         self.proctree.setColumnWidth(5, 75)
         self.proctree.setColumnWidth(6, 75)
         self.proctree.setColumnWidth(7, 75)
-        self.proctree.verticalHeader().setDefaultSectionSize(20)
         self.cntbvers.setText("Version %s" % __version__)
         self.proctree.cellClicked.connect(self.open_process_window)
         self.place_elements_on_information_tab_screen()
@@ -93,6 +93,12 @@ class MainWind(QMainWindow, Ui_mainwind):
         self.prepare_bottombar_contents()
         self.prepare_performance_donut_charts()
 
+    def initialize_window_on_screen_center(self):
+        rectfrme = self.frameGeometry()
+        cntrloca = QDesktopWidget().availableGeometry().center()
+        rectfrme.moveCenter(cntrloca)
+        self.move(rectfrme.topLeft())
+
     def prepare_threaded_worker(self):
         self.obj.thrdstat.connect(self.place_threaded_statistics_on_screen)
         self.obj.moveToThread(self.thread)
@@ -257,6 +263,7 @@ class MainWind(QMainWindow, Ui_mainwind):
         self.procqant.setText("%d processes" % statdict["procscreen"]["process_count"])
         self.proctree.setRowCount(0)
         self.proctree.insertRow(0)
+        self.proctree.verticalHeader().setDefaultSectionSize(20)
         for row, form in enumerate(statdict["procscreen"]["process_list"]):
             for column, item in enumerate(form):
                 self.proctree.setItem(row, column, QTableWidgetItem(str(item)))
